@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 BEGIN {
-  $Devel::PatchPerl::VERSION = '0.32';
+  $Devel::PatchPerl::VERSION = '0.34';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPort's buildperl.pl
@@ -128,6 +128,7 @@ my @patch = (
             ],
     subs => [
               [ \&_patch_archive_tar_tests ],
+              [ \&_patch_odbm_file_hints_linux ],
             ],
   },
 );
@@ -1688,6 +1689,25 @@ END
   }
 }
 
+sub _patch_odbm_file_hints_linux
+{
+    _patch(<<'END');
+--- ext/ODBM_File/hints/linux.pl
++++ ext/ODBM_File/hints/linux.pl
+@@ -1,8 +1,8 @@
+ # uses GDBM dbm compatibility feature - at least on SuSE 8.0
+ $self->{LIBS} = ['-lgdbm'];
+ 
+-# Debian/Ubuntu have /usr/lib/libgdbm_compat.so.3* but not this file,
++# Debian/Ubuntu have libgdbm_compat.so but not this file,
+ # so linking may fail
+-if (-e '/usr/lib/libgdbm_compat.so' or -e '/usr/lib64/libgdbm_compat.so') {
+-    $self->{LIBS}->[0] .= ' -lgdbm_compat';
++foreach (split / /, $Config{libpth}) {
++    $self->{LIBS}->[0] .= ' -lgdbm_compat' if -e $_.'/libgdbm_compat.so';
+ }
+END
+}
 
 qq[patchin'];
 
@@ -1702,7 +1722,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.32
+version 0.34
 
 =head1 SYNOPSIS
 
